@@ -1,13 +1,10 @@
 """
-    MobileNet & FD-MobileNet for ImageNet-1K, implemented in PyTorch.
-    Original papers:
-    - 'MobileNets: Efficient Convolutional Neural Networks for Mobile Vision Applications,'
-       https://arxiv.org/abs/1704.04861.
-    - 'FD-MobileNet: Improved MobileNet with A Fast Downsampling Strategy,' https://arxiv.org/abs/1802.03750.
+    MobileNet for ImageNet-1K, implemented in PyTorch.
+    Original paper: 'MobileNets: Efficient Convolutional Neural Networks for Mobile Vision Applications,'
+    https://arxiv.org/abs/1704.04861.
 """
 
-__all__ = ['MobileNet', 'mobilenet_w1', 'mobilenet_w3d4', 'mobilenet_wd2', 'mobilenet_wd4', 'fdmobilenet_w1',
-           'fdmobilenet_w3d4', 'fdmobilenet_wd2', 'fdmobilenet_wd4']
+__all__ = ['MobileNet', 'mobilenet_w1', 'mobilenet_w3d4', 'mobilenet_wd2', 'mobilenet_wd4', 'get_mobilenet']
 
 import os
 import torch.nn as nn
@@ -17,8 +14,7 @@ from .common import conv3x3_block, dwsconv3x3_block
 class MobileNet(nn.Module):
     """
     MobileNet model from 'MobileNets: Efficient Convolutional Neural Networks for Mobile Vision Applications,'
-    https://arxiv.org/abs/1704.04861. Also this class implements FD-MobileNet from 'FD-MobileNet: Improved MobileNet
-    with A Fast Downsampling Strategy,' https://arxiv.org/abs/1802.03750.
+    https://arxiv.org/abs/1704.04861.
 
     Parameters:
     ----------
@@ -26,6 +22,10 @@ class MobileNet(nn.Module):
         Number of output channels for each unit.
     first_stage_stride : bool
         Whether stride is used at the first stage.
+    dw_use_bn : bool, default True
+        Whether to use BatchNorm layer (depthwise convolution block).
+    dw_activation : function or str or None, default nn.ReLU(inplace=True)
+        Activation function after the depthwise convolution block.
     in_channels : int, default 3
         Number of input channels.
     in_size : tuple of two ints, default (224, 224)
@@ -36,6 +36,8 @@ class MobileNet(nn.Module):
     def __init__(self,
                  channels,
                  first_stage_stride,
+                 dw_use_bn=True,
+                 dw_activation=(lambda: nn.ReLU(inplace=True)),
                  in_channels=3,
                  in_size=(224, 224),
                  num_classes=1000):
@@ -57,7 +59,9 @@ class MobileNet(nn.Module):
                 stage.add_module("unit{}".format(j + 1), dwsconv3x3_block(
                     in_channels=in_channels,
                     out_channels=out_channels,
-                    stride=stride))
+                    stride=stride,
+                    dw_use_bn=dw_use_bn,
+                    dw_activation=dw_activation))
                 in_channels = out_channels
             self.features.add_module("stage{}".format(i + 1), stage)
         self.features.add_module("final_pool", nn.AvgPool2d(
@@ -90,21 +94,21 @@ class MobileNet(nn.Module):
         return x
 
 
-def get_mobilenet(version,
-                  width_scale,
+def get_mobilenet(width_scale,
+                  dws_simplified=False,
                   model_name=None,
                   pretrained=False,
                   root=os.path.join("~", ".torch", "models"),
                   **kwargs):
     """
-    Create MobileNet or FD-MobileNet model with specific parameters.
+    Create MobileNet model with specific parameters.
 
     Parameters:
     ----------
-    version : str
-        Version of SqueezeNet ('orig' or 'fd').
     width_scale : float
         Scale factor for width of layers.
+    dws_simplified : bool, default False
+        Whether to use simplified depthwise separable convolution block.
     model_name : str or None, default None
         Model name for loading pretrained model.
     pretrained : bool, default False
@@ -112,22 +116,24 @@ def get_mobilenet(version,
     root : str, default '~/.torch/models'
         Location for keeping the model parameters.
     """
-
-    if version == 'orig':
-        channels = [[32], [64], [128, 128], [256, 256], [512, 512, 512, 512, 512, 512], [1024, 1024]]
-        first_stage_stride = False
-    elif version == 'fd':
-        channels = [[32], [64], [128, 128], [256, 256], [512, 512, 512, 512, 512, 1024]]
-        first_stage_stride = True
-    else:
-        raise ValueError("Unsupported MobileNet version {}".format(version))
+    channels = [[32], [64], [128, 128], [256, 256], [512, 512, 512, 512, 512, 512], [1024, 1024]]
+    first_stage_stride = False
 
     if width_scale != 1.0:
         channels = [[int(cij * width_scale) for cij in ci] for ci in channels]
 
+    if dws_simplified:
+        dw_use_bn = False
+        dw_activation = None
+    else:
+        dw_use_bn = True
+        dw_activation = (lambda: nn.ReLU(inplace=True))
+
     net = MobileNet(
         channels=channels,
         first_stage_stride=first_stage_stride,
+        dw_use_bn=dw_use_bn,
+        dw_activation=dw_activation,
         **kwargs)
 
     if pretrained:
@@ -154,7 +160,7 @@ def mobilenet_w1(**kwargs):
     root : str, default '~/.torch/models'
         Location for keeping the model parameters.
     """
-    return get_mobilenet(version="orig", width_scale=1.0, model_name="mobilenet_w1", **kwargs)
+    return get_mobilenet(width_scale=1.0, model_name="mobilenet_w1", **kwargs)
 
 
 def mobilenet_w3d4(**kwargs):
@@ -169,7 +175,7 @@ def mobilenet_w3d4(**kwargs):
     root : str, default '~/.torch/models'
         Location for keeping the model parameters.
     """
-    return get_mobilenet(version="orig", width_scale=0.75, model_name="mobilenet_w3d4", **kwargs)
+    return get_mobilenet(width_scale=0.75, model_name="mobilenet_w3d4", **kwargs)
 
 
 def mobilenet_wd2(**kwargs):
@@ -184,7 +190,7 @@ def mobilenet_wd2(**kwargs):
     root : str, default '~/.torch/models'
         Location for keeping the model parameters.
     """
-    return get_mobilenet(version="orig", width_scale=0.5, model_name="mobilenet_wd2", **kwargs)
+    return get_mobilenet(width_scale=0.5, model_name="mobilenet_wd2", **kwargs)
 
 
 def mobilenet_wd4(**kwargs):
@@ -199,67 +205,7 @@ def mobilenet_wd4(**kwargs):
     root : str, default '~/.torch/models'
         Location for keeping the model parameters.
     """
-    return get_mobilenet(version="orig", width_scale=0.25, model_name="mobilenet_wd4", **kwargs)
-
-
-def fdmobilenet_w1(**kwargs):
-    """
-    FD-MobileNet 1.0x model from 'FD-MobileNet: Improved MobileNet with A Fast Downsampling Strategy,'
-    https://arxiv.org/abs/1802.03750.
-
-    Parameters:
-    ----------
-    pretrained : bool, default False
-        Whether to load the pretrained weights for model.
-    root : str, default '~/.torch/models'
-        Location for keeping the model parameters.
-    """
-    return get_mobilenet(version="fd", width_scale=1.0, model_name="fdmobilenet_w1", **kwargs)
-
-
-def fdmobilenet_w3d4(**kwargs):
-    """
-    FD-MobileNet 0.75x model from 'FD-MobileNet: Improved MobileNet with A Fast Downsampling Strategy,'
-    https://arxiv.org/abs/1802.03750.
-
-    Parameters:
-    ----------
-    pretrained : bool, default False
-        Whether to load the pretrained weights for model.
-    root : str, default '~/.torch/models'
-        Location for keeping the model parameters.
-    """
-    return get_mobilenet(version="fd", width_scale=0.75, model_name="fdmobilenet_w3d4", **kwargs)
-
-
-def fdmobilenet_wd2(**kwargs):
-    """
-    FD-MobileNet 0.5x model from 'FD-MobileNet: Improved MobileNet with A Fast Downsampling Strategy,'
-    https://arxiv.org/abs/1802.03750.
-
-    Parameters:
-    ----------
-    pretrained : bool, default False
-        Whether to load the pretrained weights for model.
-    root : str, default '~/.torch/models'
-        Location for keeping the model parameters.
-    """
-    return get_mobilenet(version="fd", width_scale=0.5, model_name="fdmobilenet_wd2", **kwargs)
-
-
-def fdmobilenet_wd4(**kwargs):
-    """
-    FD-MobileNet 0.25x model from 'FD-MobileNet: Improved MobileNet with A Fast Downsampling Strategy,'
-    https://arxiv.org/abs/1802.03750.
-
-    Parameters:
-    ----------
-    pretrained : bool, default False
-        Whether to load the pretrained weights for model.
-    root : str, default '~/.torch/models'
-        Location for keeping the model parameters.
-    """
-    return get_mobilenet(version="fd", width_scale=0.25, model_name="fdmobilenet_wd4", **kwargs)
+    return get_mobilenet(width_scale=0.25, model_name="mobilenet_wd4", **kwargs)
 
 
 def _calc_width(net):
@@ -281,10 +227,6 @@ def _test():
         mobilenet_w3d4,
         mobilenet_wd2,
         mobilenet_wd4,
-        fdmobilenet_w1,
-        fdmobilenet_w3d4,
-        fdmobilenet_wd2,
-        fdmobilenet_wd4,
     ]
 
     for model in models:
@@ -299,10 +241,6 @@ def _test():
         assert (model != mobilenet_w3d4 or weight_count == 2585560)
         assert (model != mobilenet_wd2 or weight_count == 1331592)
         assert (model != mobilenet_wd4 or weight_count == 470072)
-        assert (model != fdmobilenet_w1 or weight_count == 2901288)
-        assert (model != fdmobilenet_w3d4 or weight_count == 1833304)
-        assert (model != fdmobilenet_wd2 or weight_count == 993928)
-        assert (model != fdmobilenet_wd4 or weight_count == 383160)
 
         x = torch.randn(1, 3, 224, 224)
         y = net(x)
