@@ -1,13 +1,15 @@
 """
-    PyramidNet for CIFAR, implemented in PyTorch.
+    PyramidNet for CIFAR/SVHN, implemented in PyTorch.
     Original paper: 'Deep Pyramidal Residual Networks,' https://arxiv.org/abs/1610.02915.
 """
 
-__all__ = ['CIFARPyramidNet', 'pyramidnet110_a48_cifar10', 'pyramidnet110_a48_cifar100', 'pyramidnet110_a84_cifar10',
-           'pyramidnet110_a84_cifar100', 'pyramidnet110_a270_cifar10', 'pyramidnet110_a270_cifar100',
-           'pyramidnet164_a270_bn_cifar10', 'pyramidnet164_a270_bn_cifar100', 'pyramidnet200_a240_bn_cifar10',
-           'pyramidnet200_a240_bn_cifar100', 'pyramidnet236_a220_bn_cifar10', 'pyramidnet236_a220_bn_cifar100',
-           'pyramidnet272_a200_bn_cifar10', 'pyramidnet272_a200_bn_cifar100']
+__all__ = ['CIFARPyramidNet', 'pyramidnet110_a48_cifar10', 'pyramidnet110_a48_cifar100', 'pyramidnet110_a48_svhn',
+           'pyramidnet110_a84_cifar10', 'pyramidnet110_a84_cifar100', 'pyramidnet110_a84_svhn',
+           'pyramidnet110_a270_cifar10', 'pyramidnet110_a270_cifar100', 'pyramidnet110_a270_svhn',
+           'pyramidnet164_a270_bn_cifar10', 'pyramidnet164_a270_bn_cifar100', 'pyramidnet164_a270_bn_svhn',
+           'pyramidnet200_a240_bn_cifar10', 'pyramidnet200_a240_bn_cifar100', 'pyramidnet200_a240_bn_svhn',
+           'pyramidnet236_a220_bn_cifar10', 'pyramidnet236_a220_bn_cifar100', 'pyramidnet236_a220_bn_svhn',
+           'pyramidnet272_a200_bn_cifar10', 'pyramidnet272_a200_bn_cifar100', 'pyramidnet272_a200_bn_svhn']
 
 import os
 import torch.nn as nn
@@ -51,8 +53,7 @@ class CIFARPyramidNet(nn.Module):
         self.features.add_module("init_block", conv3x3_block(
             in_channels=in_channels,
             out_channels=init_block_channels,
-            activation=None,
-            activate=False))
+            activation=None))
         in_channels = init_block_channels
         for i, channels_per_stage in enumerate(channels):
             stage = nn.Sequential()
@@ -65,8 +66,8 @@ class CIFARPyramidNet(nn.Module):
                     bottleneck=bottleneck))
                 in_channels = out_channels
             self.features.add_module("stage{}".format(i + 1), stage)
-        self.features.add_module('post_activ', PreResActivation(in_channels=in_channels))
-        self.features.add_module('final_pool', nn.AvgPool2d(
+        self.features.add_module("post_activ", PreResActivation(in_channels=in_channels))
+        self.features.add_module("final_pool", nn.AvgPool2d(
             kernel_size=8,
             stride=1))
 
@@ -96,7 +97,7 @@ def get_pyramidnet_cifar(num_classes,
                          bottleneck,
                          model_name=None,
                          pretrained=False,
-                         root=os.path.join('~', '.torch', 'models'),
+                         root=os.path.join("~", ".torch", "models"),
                          **kwargs):
     """
     Create PyramidNet for CIFAR model with specific parameters.
@@ -202,6 +203,28 @@ def pyramidnet110_a48_cifar100(num_classes=100, **kwargs):
         **kwargs)
 
 
+def pyramidnet110_a48_svhn(num_classes=10, **kwargs):
+    """
+    PyramidNet-110 (a=48) model for SVHN from 'Deep Pyramidal Residual Networks,' https://arxiv.org/abs/1610.02915.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_pyramidnet_cifar(
+        num_classes=num_classes,
+        blocks=110,
+        alpha=48,
+        bottleneck=False,
+        model_name="pyramidnet110_a48_svhn",
+        **kwargs)
+
+
 def pyramidnet110_a84_cifar10(num_classes=10, **kwargs):
     """
     PyramidNet-110 (a=84) model for CIFAR-10 from 'Deep Pyramidal Residual Networks,' https://arxiv.org/abs/1610.02915.
@@ -246,6 +269,28 @@ def pyramidnet110_a84_cifar100(num_classes=100, **kwargs):
         **kwargs)
 
 
+def pyramidnet110_a84_svhn(num_classes=10, **kwargs):
+    """
+    PyramidNet-110 (a=84) model for SVHN from 'Deep Pyramidal Residual Networks,' https://arxiv.org/abs/1610.02915.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_pyramidnet_cifar(
+        num_classes=num_classes,
+        blocks=110,
+        alpha=84,
+        bottleneck=False,
+        model_name="pyramidnet110_a84_svhn",
+        **kwargs)
+
+
 def pyramidnet110_a270_cifar10(num_classes=10, **kwargs):
     """
     PyramidNet-110 (a=270) model for CIFAR-10 from 'Deep Pyramidal Residual Networks,' https://arxiv.org/abs/1610.02915.
@@ -291,6 +336,28 @@ def pyramidnet110_a270_cifar100(num_classes=100, **kwargs):
         **kwargs)
 
 
+def pyramidnet110_a270_svhn(num_classes=10, **kwargs):
+    """
+    PyramidNet-110 (a=270) model for SVHN from 'Deep Pyramidal Residual Networks,' https://arxiv.org/abs/1610.02915.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_pyramidnet_cifar(
+        num_classes=num_classes,
+        blocks=110,
+        alpha=270,
+        bottleneck=False,
+        model_name="pyramidnet110_a270_svhn",
+        **kwargs)
+
+
 def pyramidnet164_a270_bn_cifar10(num_classes=10, **kwargs):
     """
     PyramidNet-164 (a=270, bn) model for CIFAR-10 from 'Deep Pyramidal Residual Networks,'
@@ -337,6 +404,29 @@ def pyramidnet164_a270_bn_cifar100(num_classes=100, **kwargs):
         **kwargs)
 
 
+def pyramidnet164_a270_bn_svhn(num_classes=10, **kwargs):
+    """
+    PyramidNet-164 (a=270, bn) model for SVHN from 'Deep Pyramidal Residual Networks,'
+    https://arxiv.org/abs/1610.02915.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_pyramidnet_cifar(
+        num_classes=num_classes,
+        blocks=164,
+        alpha=270,
+        bottleneck=True,
+        model_name="pyramidnet164_a270_bn_svhn",
+        **kwargs)
+
+
 def pyramidnet200_a240_bn_cifar10(num_classes=10, **kwargs):
     """
     PyramidNet-200 (a=240, bn) model for CIFAR-10 from 'Deep Pyramidal Residual Networks,'
@@ -383,6 +473,29 @@ def pyramidnet200_a240_bn_cifar100(num_classes=100, **kwargs):
         **kwargs)
 
 
+def pyramidnet200_a240_bn_svhn(num_classes=10, **kwargs):
+    """
+    PyramidNet-200 (a=240, bn) model for SVHN from 'Deep Pyramidal Residual Networks,'
+    https://arxiv.org/abs/1610.02915.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_pyramidnet_cifar(
+        num_classes=num_classes,
+        blocks=200,
+        alpha=240,
+        bottleneck=True,
+        model_name="pyramidnet200_a240_bn_svhn",
+        **kwargs)
+
+
 def pyramidnet236_a220_bn_cifar10(num_classes=10, **kwargs):
     """
     PyramidNet-236 (a=220, bn) model for CIFAR-10 from 'Deep Pyramidal Residual Networks,'
@@ -429,6 +542,29 @@ def pyramidnet236_a220_bn_cifar100(num_classes=100, **kwargs):
         **kwargs)
 
 
+def pyramidnet236_a220_bn_svhn(num_classes=10, **kwargs):
+    """
+    PyramidNet-236 (a=220, bn) model for SVHN from 'Deep Pyramidal Residual Networks,'
+    https://arxiv.org/abs/1610.02915.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_pyramidnet_cifar(
+        num_classes=num_classes,
+        blocks=236,
+        alpha=220,
+        bottleneck=True,
+        model_name="pyramidnet236_a220_bn_svhn",
+        **kwargs)
+
+
 def pyramidnet272_a200_bn_cifar10(num_classes=10, **kwargs):
     """
     PyramidNet-272 (a=200, bn) model for CIFAR-10 from 'Deep Pyramidal Residual Networks,'
@@ -475,6 +611,29 @@ def pyramidnet272_a200_bn_cifar100(num_classes=100, **kwargs):
         **kwargs)
 
 
+def pyramidnet272_a200_bn_svhn(num_classes=10, **kwargs):
+    """
+    PyramidNet-272 (a=200, bn) model for SVHN from 'Deep Pyramidal Residual Networks,'
+    https://arxiv.org/abs/1610.02915.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_pyramidnet_cifar(
+        num_classes=num_classes,
+        blocks=272,
+        alpha=200,
+        bottleneck=True,
+        model_name="pyramidnet272_a200_bn_svhn",
+        **kwargs)
+
+
 def _calc_width(net):
     import numpy as np
     net_params = filter(lambda p: p.requires_grad, net.parameters())
@@ -486,25 +645,31 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
     models = [
         (pyramidnet110_a48_cifar10, 10),
         (pyramidnet110_a48_cifar100, 100),
+        (pyramidnet110_a48_svhn, 10),
         (pyramidnet110_a84_cifar10, 10),
         (pyramidnet110_a84_cifar100, 100),
+        (pyramidnet110_a84_svhn, 10),
         (pyramidnet110_a270_cifar10, 10),
         (pyramidnet110_a270_cifar100, 100),
+        (pyramidnet110_a270_svhn, 10),
         (pyramidnet164_a270_bn_cifar10, 10),
         (pyramidnet164_a270_bn_cifar100, 100),
+        (pyramidnet164_a270_bn_svhn, 10),
         (pyramidnet200_a240_bn_cifar10, 10),
         (pyramidnet200_a240_bn_cifar100, 100),
+        (pyramidnet200_a240_bn_svhn, 10),
         (pyramidnet236_a220_bn_cifar10, 10),
         (pyramidnet236_a220_bn_cifar100, 100),
+        (pyramidnet236_a220_bn_svhn, 10),
         (pyramidnet272_a200_bn_cifar10, 10),
         (pyramidnet272_a200_bn_cifar100, 100),
+        (pyramidnet272_a200_bn_svhn, 10),
     ]
 
     for model, num_classes in models:
@@ -517,20 +682,27 @@ def _test():
         print("m={}, {}".format(model.__name__, weight_count))
         assert (model != pyramidnet110_a48_cifar10 or weight_count == 1772706)
         assert (model != pyramidnet110_a48_cifar100 or weight_count == 1778556)
+        assert (model != pyramidnet110_a48_svhn or weight_count == 1772706)
         assert (model != pyramidnet110_a84_cifar10 or weight_count == 3904446)
         assert (model != pyramidnet110_a84_cifar100 or weight_count == 3913536)
+        assert (model != pyramidnet110_a84_svhn or weight_count == 3904446)
         assert (model != pyramidnet110_a270_cifar10 or weight_count == 28485477)
         assert (model != pyramidnet110_a270_cifar100 or weight_count == 28511307)
+        assert (model != pyramidnet110_a270_svhn or weight_count == 28485477)
         assert (model != pyramidnet164_a270_bn_cifar10 or weight_count == 27216021)
         assert (model != pyramidnet164_a270_bn_cifar100 or weight_count == 27319071)
+        assert (model != pyramidnet164_a270_bn_svhn or weight_count == 27216021)
         assert (model != pyramidnet200_a240_bn_cifar10 or weight_count == 26752702)
         assert (model != pyramidnet200_a240_bn_cifar100 or weight_count == 26844952)
+        assert (model != pyramidnet200_a240_bn_svhn or weight_count == 26752702)
         assert (model != pyramidnet236_a220_bn_cifar10 or weight_count == 26969046)
         assert (model != pyramidnet236_a220_bn_cifar100 or weight_count == 27054096)
+        assert (model != pyramidnet236_a220_bn_svhn or weight_count == 26969046)
         assert (model != pyramidnet272_a200_bn_cifar10 or weight_count == 26210842)
         assert (model != pyramidnet272_a200_bn_cifar100 or weight_count == 26288692)
+        assert (model != pyramidnet272_a200_bn_svhn or weight_count == 26210842)
 
-        x = Variable(torch.randn(1, 3, 32, 32))
+        x = torch.randn(1, 3, 32, 32)
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, num_classes))
