@@ -3,9 +3,10 @@
     Original paper: 'Deep Residual Learning for Image Recognition,' https://arxiv.org/abs/1512.03385.
 """
 
-__all__ = ['ResNet', 'resnet10', 'resnet12', 'resnet14', 'resnet16', 'resnet18_wd4', 'resnet18_wd2', 'resnet18_w3d4',
-           'resnet18', 'resnet34', 'resnet50', 'resnet50b', 'resnet101', 'resnet101b', 'resnet152', 'resnet152b',
-           'resnet200', 'resnet200b', 'ResBlock', 'ResBottleneck', 'ResUnit', 'ResInitBlock']
+__all__ = ['ResNet', 'resnet10', 'resnet12', 'resnet14', 'resnetbc14b', 'resnet16', 'resnet18_wd4', 'resnet18_wd2',
+           'resnet18_w3d4', 'resnet18', 'resnet26', 'resnetbc26b', 'resnet34', 'resnetbc38b', 'resnet50', 'resnet50b',
+           'resnet101', 'resnet101b', 'resnet152', 'resnet152b', 'resnet200', 'resnet200b', 'ResBlock', 'ResBottleneck',
+           'ResUnit', 'ResInitBlock']
 
 import os
 import torch.nn as nn
@@ -25,21 +26,30 @@ class ResBlock(nn.Module):
         Number of output channels.
     stride : int or tuple/list of 2 int
         Strides of the convolution.
+    bias : bool, default False
+        Whether the layer uses a bias vector.
+    use_bn : bool, default True
+        Whether to use BatchNorm layer.
     """
     def __init__(self,
                  in_channels,
                  out_channels,
-                 stride):
+                 stride,
+                 bias=False,
+                 use_bn=True):
         super(ResBlock, self).__init__()
         self.conv1 = conv3x3_block(
             in_channels=in_channels,
             out_channels=out_channels,
-            stride=stride)
+            stride=stride,
+            bias=bias,
+            use_bn=use_bn)
         self.conv2 = conv3x3_block(
             in_channels=out_channels,
             out_channels=out_channels,
-            activation=None,
-            activate=False)
+            bias=bias,
+            use_bn=use_bn,
+            activation=None)
 
     def forward(self, x):
         x = self.conv1(x)
@@ -59,6 +69,10 @@ class ResBottleneck(nn.Module):
         Number of output channels.
     stride : int or tuple/list of 2 int
         Strides of the convolution.
+    padding : int or tuple/list of 2 int, default 1
+        Padding value for the second convolution layer.
+    dilation : int or tuple/list of 2 int, default 1
+        Dilation value for the second convolution layer.
     conv1_stride : bool, default False
         Whether to use stride in the first or the second convolution layer of the block.
     bottleneck_factor : int, default 4
@@ -68,6 +82,8 @@ class ResBottleneck(nn.Module):
                  in_channels,
                  out_channels,
                  stride,
+                 padding=1,
+                 dilation=1,
                  conv1_stride=False,
                  bottleneck_factor=4):
         super(ResBottleneck, self).__init__()
@@ -80,12 +96,13 @@ class ResBottleneck(nn.Module):
         self.conv2 = conv3x3_block(
             in_channels=mid_channels,
             out_channels=mid_channels,
-            stride=(1 if conv1_stride else stride))
+            stride=(1 if conv1_stride else stride),
+            padding=padding,
+            dilation=dilation)
         self.conv3 = conv1x1_block(
             in_channels=mid_channels,
             out_channels=out_channels,
-            activation=None,
-            activate=False)
+            activation=None)
 
     def forward(self, x):
         x = self.conv1(x)
@@ -106,17 +123,29 @@ class ResUnit(nn.Module):
         Number of output channels.
     stride : int or tuple/list of 2 int
         Strides of the convolution.
-    bottleneck : bool
+    padding : int or tuple/list of 2 int, default 1
+        Padding value for the second convolution layer in bottleneck.
+    dilation : int or tuple/list of 2 int, default 1
+        Dilation value for the second convolution layer in bottleneck.
+    bias : bool, default False
+        Whether the layer uses a bias vector.
+    use_bn : bool, default True
+        Whether to use BatchNorm layer.
+    bottleneck : bool, default True
         Whether to use a bottleneck or simple block in units.
-    conv1_stride : bool
+    conv1_stride : bool, default False
         Whether to use stride in the first or the second convolution layer of the block.
     """
     def __init__(self,
                  in_channels,
                  out_channels,
                  stride,
-                 bottleneck,
-                 conv1_stride):
+                 padding=1,
+                 dilation=1,
+                 bias=False,
+                 use_bn=True,
+                 bottleneck=True,
+                 conv1_stride=False):
         super(ResUnit, self).__init__()
         self.resize_identity = (in_channels != out_channels) or (stride != 1)
 
@@ -125,19 +154,24 @@ class ResUnit(nn.Module):
                 in_channels=in_channels,
                 out_channels=out_channels,
                 stride=stride,
+                padding=padding,
+                dilation=dilation,
                 conv1_stride=conv1_stride)
         else:
             self.body = ResBlock(
                 in_channels=in_channels,
                 out_channels=out_channels,
-                stride=stride)
+                stride=stride,
+                bias=bias,
+                use_bn=use_bn)
         if self.resize_identity:
             self.identity_conv = conv1x1_block(
                 in_channels=in_channels,
                 out_channels=out_channels,
                 stride=stride,
-                activation=None,
-                activate=False)
+                bias=bias,
+                use_bn=use_bn,
+                activation=None)
         self.activ = nn.ReLU(inplace=True)
 
     def forward(self, x):
@@ -256,11 +290,12 @@ class ResNet(nn.Module):
 
 
 def get_resnet(blocks,
+               bottleneck=None,
                conv1_stride=True,
                width_scale=1.0,
                model_name=None,
                pretrained=False,
-               root=os.path.join('~', '.torch', 'models'),
+               root=os.path.join("~", ".torch", "models"),
                **kwargs):
     """
     Create ResNet model with specific parameters.
@@ -269,6 +304,8 @@ def get_resnet(blocks,
     ----------
     blocks : int
         Number of blocks.
+    bottleneck : bool, default None
+        Whether to use a bottleneck or simple block in units.
     conv1_stride : bool, default True
         Whether to use stride in the first or the second convolution layer in units.
     width_scale : float, default 1.0
@@ -280,19 +317,29 @@ def get_resnet(blocks,
     root : str, default '~/.torch/models'
         Location for keeping the model parameters.
     """
+    if bottleneck is None:
+        bottleneck = (blocks >= 50)
 
     if blocks == 10:
         layers = [1, 1, 1, 1]
     elif blocks == 12:
         layers = [2, 1, 1, 1]
-    elif blocks == 14:
+    elif blocks == 14 and not bottleneck:
         layers = [2, 2, 1, 1]
+    elif (blocks == 14) and bottleneck:
+        layers = [1, 1, 1, 1]
     elif blocks == 16:
         layers = [2, 2, 2, 1]
     elif blocks == 18:
         layers = [2, 2, 2, 2]
+    elif (blocks == 26) and not bottleneck:
+        layers = [3, 3, 3, 3]
+    elif (blocks == 26) and bottleneck:
+        layers = [2, 2, 2, 2]
     elif blocks == 34:
         layers = [3, 4, 6, 3]
+    elif (blocks == 38) and bottleneck:
+        layers = [3, 3, 3, 3]
     elif blocks == 50:
         layers = [3, 4, 6, 3]
     elif blocks == 101:
@@ -304,19 +351,21 @@ def get_resnet(blocks,
     else:
         raise ValueError("Unsupported ResNet with number of blocks: {}".format(blocks))
 
-    init_block_channels = 64
-
-    if blocks < 50:
-        channels_per_layers = [64, 128, 256, 512]
-        bottleneck = False
+    if bottleneck:
+        assert (sum(layers) * 3 + 2 == blocks)
     else:
-        channels_per_layers = [256, 512, 1024, 2048]
-        bottleneck = True
+        assert (sum(layers) * 2 + 2 == blocks)
+
+    init_block_channels = 64
+    channels_per_layers = [64, 128, 256, 512]
+
+    if bottleneck:
+        bottleneck_factor = 4
+        channels_per_layers = [ci * bottleneck_factor for ci in channels_per_layers]
 
     channels = [[ci] * li for (ci, li) in zip(channels_per_layers, layers)]
 
     if width_scale != 1.0:
-        # channels = [[int(cij * width_scale) for cij in ci] for ci in channels]
         channels = [[int(cij * width_scale) if (i != len(channels) - 1) or (j != len(ci) - 1) else cij
                      for j, cij in enumerate(ci)] for i, ci in enumerate(channels)]
         init_block_channels = int(init_block_channels * width_scale)
@@ -385,6 +434,21 @@ def resnet14(**kwargs):
     return get_resnet(blocks=14, model_name="resnet14", **kwargs)
 
 
+def resnetbc14b(**kwargs):
+    """
+    ResNet-BC-14b model from 'Deep Residual Learning for Image Recognition,' https://arxiv.org/abs/1512.03385.
+    It's an experimental model (bottleneck compressed).
+
+    Parameters:
+    ----------
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_resnet(blocks=14, bottleneck=True, conv1_stride=False, model_name="resnetbc14b", **kwargs)
+
+
 def resnet16(**kwargs):
     """
     ResNet-16 model from 'Deep Residual Learning for Image Recognition,' https://arxiv.org/abs/1512.03385.
@@ -459,6 +523,36 @@ def resnet18(**kwargs):
     return get_resnet(blocks=18, model_name="resnet18", **kwargs)
 
 
+def resnet26(**kwargs):
+    """
+    ResNet-26 model from 'Deep Residual Learning for Image Recognition,' https://arxiv.org/abs/1512.03385.
+    It's an experimental model.
+
+    Parameters:
+    ----------
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_resnet(blocks=26, bottleneck=False, model_name="resnet26", **kwargs)
+
+
+def resnetbc26b(**kwargs):
+    """
+    ResNet-BC-26b model from 'Deep Residual Learning for Image Recognition,' https://arxiv.org/abs/1512.03385.
+    It's an experimental model (bottleneck compressed).
+
+    Parameters:
+    ----------
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_resnet(blocks=26, bottleneck=True, conv1_stride=False, model_name="resnetbc26b", **kwargs)
+
+
 def resnet34(**kwargs):
     """
     ResNet-34 model from 'Deep Residual Learning for Image Recognition,' https://arxiv.org/abs/1512.03385.
@@ -473,6 +567,21 @@ def resnet34(**kwargs):
     return get_resnet(blocks=34, model_name="resnet34", **kwargs)
 
 
+def resnetbc38b(**kwargs):
+    """
+    ResNet-BC-38b model from 'Deep Residual Learning for Image Recognition,' https://arxiv.org/abs/1512.03385.
+    It's an experimental model (bottleneck compressed).
+
+    Parameters:
+    ----------
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_resnet(blocks=38, bottleneck=True, conv1_stride=False, model_name="resnetbc38b", **kwargs)
+
+
 def resnet50(**kwargs):
     """
     ResNet-50 model from 'Deep Residual Learning for Image Recognition,' https://arxiv.org/abs/1512.03385.
@@ -601,7 +710,6 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
@@ -609,13 +717,16 @@ def _test():
         resnet10,
         resnet12,
         resnet14,
+        resnetbc14b,
         resnet16,
         resnet18_wd4,
         resnet18_wd2,
         resnet18_w3d4,
-
         resnet18,
+        resnet26,
+        resnetbc26b,
         resnet34,
+        resnetbc38b,
         resnet50,
         resnet50b,
         resnet101,
@@ -637,12 +748,16 @@ def _test():
         assert (model != resnet10 or weight_count == 5418792)
         assert (model != resnet12 or weight_count == 5492776)
         assert (model != resnet14 or weight_count == 5788200)
+        assert (model != resnetbc14b or weight_count == 10064936)
         assert (model != resnet16 or weight_count == 6968872)
-        assert (model != resnet18_wd4 or weight_count == 3937400)  # 831096
-        assert (model != resnet18_wd2 or weight_count == 5804296)  # 3055880
-        assert (model != resnet18_w3d4 or weight_count == 8476056)  # 6675352
+        assert (model != resnet18_wd4 or weight_count == 3937400)
+        assert (model != resnet18_wd2 or weight_count == 5804296)
+        assert (model != resnet18_w3d4 or weight_count == 8476056)
         assert (model != resnet18 or weight_count == 11689512)
+        assert (model != resnet26 or weight_count == 17960232)
+        assert (model != resnetbc26b or weight_count == 15995176)
         assert (model != resnet34 or weight_count == 21797672)
+        assert (model != resnetbc38b or weight_count == 21925416)
         assert (model != resnet50 or weight_count == 25557032)
         assert (model != resnet50b or weight_count == 25557032)
         assert (model != resnet101 or weight_count == 44549160)
@@ -652,7 +767,7 @@ def _test():
         assert (model != resnet200 or weight_count == 64673832)
         assert (model != resnet200b or weight_count == 64673832)
 
-        x = Variable(torch.randn(1, 3, 224, 224))
+        x = torch.randn(1, 3, 224, 224)
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, 1000))
