@@ -113,7 +113,7 @@ class DwsConvBlock(nn.Module):
                  pw_activation=(lambda: nn.ReLU(inplace=True)),
                  se_reduction=0):
         super(DwsConvBlock, self).__init__()
-        self.use_se = se_reduction > 0
+        self.use_se = (se_reduction > 0)
 
         self.dw_conv = dwconv_block(
             in_channels=in_channels,
@@ -935,13 +935,12 @@ class SINet(nn.Module):
         y3, y2, y1 = self.encoder(x)
         x = self.decoder(y3, y2, y1)
         if self.aux:
-            return y3, x
+            return x, y3
         else:
             return x
 
 
-def get_sinet(aux=False,
-              model_name=None,
+def get_sinet(model_name=None,
               pretrained=False,
               root=os.path.join("~", ".torch", "models"),
               **kwargs):
@@ -950,8 +949,6 @@ def get_sinet(aux=False,
 
     Parameters:
     ----------
-    aux : bool, default False
-        Whether to output an auxiliary result.
     model_name : str or None, default None
         Model name for loading pretrained model.
     pretrained : bool, default False
@@ -989,7 +986,6 @@ def get_sinet(aux=False,
         scale_factors_list=scale_factors_list,
         use_residual_list=use_residual_list,
         dim2=dims[1],
-        aux=aux,
         **kwargs)
 
     if pretrained:
@@ -1004,7 +1000,7 @@ def get_sinet(aux=False,
     return net
 
 
-def sinet_cityscapes(num_classes=19, aux=False, **kwargs):
+def sinet_cityscapes(num_classes=19, **kwargs):
     """
     SINet model for Cityscapes from 'SINet: Extreme Lightweight Portrait Segmentation Networks with Spatial Squeeze
     Modules and Information Blocking Decoder,' https://arxiv.org/abs/1911.09099.
@@ -1013,14 +1009,12 @@ def sinet_cityscapes(num_classes=19, aux=False, **kwargs):
     ----------
     num_classes : int, default 19
         Number of segmentation classes.
-    aux : bool, default True
-        Whether to output an auxiliary result.
     pretrained : bool, default False
         Whether to load the pretrained weights for model.
     root : str, default '~/.torch/models'
         Location for keeping the model parameters.
     """
-    return get_sinet(num_classes=num_classes, bn_eps=1e-3, aux=aux, model_name="sinet_cityscapes", **kwargs)
+    return get_sinet(num_classes=num_classes, bn_eps=1e-3, model_name="sinet_cityscapes", **kwargs)
 
 
 def _calc_width(net):
@@ -1054,10 +1048,12 @@ def _test():
         print("m={}, {}".format(model.__name__, weight_count))
         assert (model != sinet_cityscapes or weight_count == 119418)
 
-        x = torch.randn(14, 3, in_size[0], in_size[1])
-        y = net(x)
+        batch = 14
+        x = torch.randn(batch, 3, in_size[0], in_size[1])
+        ys = net(x)
+        y = ys[0] if aux else ys
         # y.sum().backward()
-        assert (tuple(y.size()) == (14, 19, in_size[0], in_size[1]))
+        assert (tuple(y.size()) == (batch, 19, in_size[0], in_size[1]))
 
 
 if __name__ == "__main__":
